@@ -13,13 +13,14 @@
 #include <vector>
 
 #include <KAboutData>
+#include <KCrash>
+#include <KDBusService>
 #include <KLocalizedString>
 
 #include <QString>
 #include <QList>
 #include <QByteArray>
 #include <QApplication>
-#include <KLocalizedString>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 #include <Kdelibs4ConfigMigrator>
@@ -325,6 +326,7 @@ int main(int argc, char *argv[])
     // Command line argument options
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
+    KCrash::initialize();
     parser.addVersionOption();
     parser.addHelpOption();
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("mode"), i18n("Setup kblocks game running mode.\n\t0 = Desktop Mode\t1 = Game Engine Mode\n\t2 = Gui Mode\t3 = Player Mode"), QStringLiteral("game mode"), QStringLiteral("0")));
@@ -333,6 +335,7 @@ int main(int argc, char *argv[])
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
+    KDBusService service;
 
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kblocks")));
 
